# InvitedPositionV30Rc1

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_date** | [**CreatedDateV30Rc1**](CreatedDateV30Rc1.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDateV30Rc1**](LastModifiedDateV30Rc1.md) |  | [optional] 
**source** | [**SourceV30Rc1**](SourceV30Rc1.md) |  | [optional] 
**put_code** | **int** |  | [optional] 
**path** | **str** |  | [optional] 
**department_name** | **str** |  | [optional] 
**role_title** | **str** |  | [optional] 
**start_date** | [**FuzzyDateV30Rc1**](FuzzyDateV30Rc1.md) |  | 
**end_date** | [**FuzzyDateV30Rc1**](FuzzyDateV30Rc1.md) |  | [optional] 
**organization** | [**OrganizationV30Rc1**](OrganizationV30Rc1.md) |  | 
**url** | [**UrlV30Rc1**](UrlV30Rc1.md) |  | [optional] 
**external_ids** | [**ExternalIDsV30Rc1**](ExternalIDsV30Rc1.md) |  | [optional] 
**display_index** | **str** |  | [optional] 
**visibility** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

